@@ -21,7 +21,11 @@
 #include <sys/prctl.h>
 #include <libavcodec/avcodec.h>
 #include <libswscale/swscale.h>
-#include <libavutil/imgutils.h>
+#if LIBAVUTIL_VERSION_MAJOR>50 || (LIBAVUTIL_VERSION_MAJOR==50 && LIBAVUTIL_VERSION_MINOR>37)
+  #include <libavutil/imgutils.h>
+#else
+  #include <libavcore/imgutils.h>
+#endif
 #ifdef HAVE_SOUND
 // TODO: use libavresample instead if available
   #if HAVE_SOUND==avresample
@@ -118,6 +122,28 @@ void camera_playsnd(struct viddata* data, struct camera* cam, short* samples, un
 }
 #endif
 
+void camera_remove(struct viddata* data, const char* nick)
+{
+  unsigned int i;
+  for(i=0; i<data->camcount; ++i)
+  {
+    if(!strcmp(data->cams[i].id, nick))
+    {
+      gtk_widget_destroy(data->cams[i].box);
+      av_frame_free(&data->cams[i].frame);
+      avcodec_free_context(&data->cams[i].vctx);
+#ifdef HAVE_SOUND
+      avcodec_free_context(&data->cams[i].actx);
+#endif
+      free(data->cams[i].id);
+      free(data->cams[i].nick);
+      --data->camcount;
+      memmove(&data->cams[i], &data->cams[i+1], (data->camcount-i)*sizeof(struct camera));
+      break;
+    }
+  }
+}
+
 char buf[1024];
 gboolean handledata(GIOChannel* channel, GIOCondition condition, gpointer datap)
 {
@@ -151,6 +177,13 @@ gboolean handledata(GIOChannel* channel, GIOCondition condition, gpointer datap)
     dprintf(tc_client_in[1], "/opencam %s\n", buf);
     return 1;
   }
+  // Make sure the cam goes away when a user leaves
+  else if(space && !strcmp(space, " left the channel"))
+  {
+    space[0]=0;
+    camera_remove(data, buf);
+    return 1;
+  }
   if(!strncmp(buf, "Starting media stream for ", 26))
   {
     char* nick=&buf[26];
@@ -204,23 +237,7 @@ gboolean handledata(GIOChannel* channel, GIOCondition condition, gpointer datap)
   }
   if(!strncmp(buf, "VideoEnd: ", 10))
   {
-    for(i=0; i<data->camcount; ++i)
-    {
-      if(!strcmp(data->cams[i].id, &buf[10]))
-      {
-        gtk_widget_destroy(data->cams[i].box);
-        av_frame_free(&data->cams[i].frame);
-        avcodec_free_context(&data->cams[i].vctx);
-#ifdef HAVE_SOUND
-        avcodec_free_context(&data->cams[i].actx);
-#endif
-        free(data->cams[i].id);
-        free(data->cams[i].nick);
-        --data->camcount;
-        memmove(&data->cams[i], &data->cams[i+1], (data->camcount-i)*sizeof(struct camera));
-        break;
-      }
-    }
+    camera_remove(data, &buf[10]);
     return 1;
   }
   if(!strncmp(buf, "Audio: ", 7))
@@ -350,12 +367,16 @@ void togglecam(GtkButton* button, struct viddata* data)
     dprintf(tc_client[1], "VideoEnd: out\n"); // Close our local display
     return;
   }
+  // Set up a second pipe to be handled by handledata() to avoid overlap with tc_client's output
+  int campipe[2];
+  pipe(campipe);
   dprintf(tc_client_in[1], "/camup\n");
   gtk_button_set_label(button, "Stop broadcasting");
 // printf("Camming up!\n");
   camproc=fork();
   if(!camproc)
   {
+    close(campipe[0]);
     prctl(PR_SET_PDEATHSIG, SIGHUP);
     unsigned int delay=500000;
     // Set up camera
@@ -413,15 +434,19 @@ packet.size=0;
       write(tc_client_in[1], &frameinfo, 1);
       write(tc_client_in[1], packet.data, packet.size);
       // Also send the packet to our main thread so we can see ourselves
-      dprintf(tc_client[1], "Video: out %i\n", packet.size+1);
-      write(tc_client[1], &frameinfo, 1);
-      write(tc_client[1], packet.data, packet.size);
+      dprintf(campipe[1], "Video: out %i\n", packet.size+1);
+      write(campipe[1], &frameinfo, 1);
+      write(campipe[1], packet.data, packet.size);
 
       av_free_packet(&packet);
     }
     sws_freeContext(swsctx);
     _exit(0);
   }
+  close(campipe[1]);
+  GIOChannel* channel=g_io_channel_unix_new(campipe[0]);
+  g_io_channel_set_encoding(channel, 0, 0);
+  g_io_add_watch(channel, G_IO_IN, handledata, data);
 }
 #endif
 
